:orphan:

.. _profilemode:

================================================
:mod:`profilemode` -- profiling Aesara functions
================================================


.. module:: aesara.compile.profilemode
   :platform: Unix, Windows
   :synopsis: profiling Aesara functions with ProfileMode
.. moduleauthor:: LISA

Guide
=====

.. note::

    ProfileMode is removed. Use :attr:`config.profile` instead.
